@@ -121,7 +121,7 @@ sf_text <- function(x) {
   ## If too big here, drawing bounding
   if (utils::object.size(x) > getOption("vicmap.max_geom_pred_size", 4400)) {
     message("The object is too large to perform exact spatial operations using VicmapR. 
-            To simplify the polygon, sf::st_simplify() was used to reduce the size of the query", call. = FALSE)
+            To simplify the polygon, sf::st_simplify() was used to reduce the size of the query")
     x <- polygonFormat(x)
   }
   
